@@ -8,7 +8,7 @@ use DBI;
 use DBD::SQLite;
 use JSON::XS;
 
-our $VERSION = '1.46'; # VERSION
+our $VERSION = '1.47'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -20,9 +20,11 @@ sub init {
 
 sub new {
     my ( $class, $bot ) = @_;
-    my $self = bless( {}, $class );
 
-    $self->{file} = $bot->vars('store') || 'store.sqlite';
+    my $conf = $bot->vars('store') || 'store.sqlite';
+    $conf = { file => $conf } unless ( ref $conf eq 'HASH' );
+
+    my $self = bless( $conf, $class );
     $self->{json} = JSON::XS->new->ascii;
 
     return $self;
@@ -46,16 +48,20 @@ sub _dbh {
                 # 4 = DBD_SQLITE_STRING_MODE_UNICODE_NAIVE
                 # 5 = DBD_SQLITE_STRING_MODE_UNICODE_FALLBACK
                 # 6 = DBD_SQLITE_STRING_MODE_UNICODE_STRICT
+            %{ $self->{attr} // {} },
         },
     ) or die "$@\n";
 
-    $dbh->do("PRAGMA $_->[0] = $_->[1]") for (
-        [ encoding           => '"UTF-8"'  ],
-        [ foreign_keys       => 'ON'       ],
-        [ journal_mode       => 'WAL'      ],
-        [ recursive_triggers => 'ON'       ],
-        [ temp_store         => 'MEMORY'   ],
-    );
+    my $pragma = {
+        encoding           => '"UTF-8"',
+        foreign_keys       => 'ON',
+        journal_mode       => 'DELETE',
+        recursive_triggers => 'ON',
+        synchronous        => 'FULL',
+        temp_store         => 'MEMORY',
+        %{ $self->{pragma} // {} },
+    };
+    $dbh->do( 'PRAGMA ' . $_ . ' = ' . $pragma->{$_} ) for ( keys %$pragma );
 
     $dbh->do(q{
         CREATE TABLE IF NOT EXISTS bot_store (
@@ -142,7 +148,7 @@ Bot::IRC::Store::SQLite - Bot::IRC persistent data storage with SQLite
 
 =head1 VERSION
 
-version 1.46
+version 1.47
 
 =head1 SYNOPSIS
 
@@ -151,14 +157,34 @@ version 1.46
     Bot::IRC->new(
         connect => { server => 'irc.perl.org' },
         plugins => ['Store::SQLite'],
-        vars    => { store => 'bot.sqlite' },
+        vars    => {
+            store => {
+                file => 'store.sqlite',
+                attr => {
+                    PrintError                   => 0,
+                    RaiseError                   => 1,
+                    sqlite_see_if_its_a_number   => 1,
+                    sqlite_defensive             => 1,
+                    sqlite_extended_result_codes => 1,
+                    sqlite_string_mode           => 6,
+                },
+                pragma => {
+                    encoding           => '"UTF-8"',
+                    foreign_keys       => 'ON',
+                    journal_mode       => 'DELETE',
+                    recursive_triggers => 'ON',
+                    synchronous        => 'FULL',
+                    temp_store         => 'MEMORY',
+                },
+            },
+        },
     )->run;
 
 =head1 DESCRIPTION
 
 This L<Bot::IRC> plugin provides a persistent storage mechanism with a SQLite
 database file. By default, it's the "store.sqlite" file, but this can be changed
-with the C<vars>, C<store> value.
+with the C<vars>, C<store> value (as in the above synopsis).
 
 =head1 EXAMPLE USE
 
